(function () {
    // 定义全局变量
    var callbackPrefix = "callback";  // 回调函数名前缀
    var appVersion = "1";            // 应用版本号
    var enableLog = 1;               // 是否启用日志输出（1：启用，0：禁用）
    var registeredCallbacks = {};    // 存储已注册的回调函数

    // 如果 jsbridge 已经存在，则直接返回，避免重复定义
    if (window.jsbridge) {
        return;
    }

    /**
     * jsbridge 是一个桥接对象，用于 Web 与原生应用之间的通信。
     */
    window.jsbridge = {
        /**
         * 添加一个需要调用的方法到 jsbridge 中。
         *
         * @param {Object} options - 调用配置对象
         * @param {string} options.funName - 需要调用的方法名称
         * @param {Object} [options.param] - 方法所需的参数
         * @param {Object} [options.reFun] - 回调函数对象，包含 onSuccess 和 onFail 方法
         * @param {number} [options.staticType] - 回调类型标识（0：一次性回调，1：持久性回调）
         */
        add: function (options) {
            // 检查是否提供了方法名
            if (!options.funName) {
                console.warn("未提供 funName，无法执行 add 方法");
                return false;
            }

            var callbackKey = void 0;

            // 如果提供了回调函数，并且是对象类型且包含 onSuccess 方法
            if (null !== options.reFun &&
                typeof options.reFun === "object" &&
                options.reFun.onSuccess) {

                // 记录日志
                enableLog && console.log("004------------------>");

                // 记录 reFun 的详细信息
                enableLog && console.log(options.reFun);

                // 根据 staticType 决定是否生成唯一回调键
                callbackKey = options.staticType === 0 ? callbackPrefix + options.funName + (new Date()).getTime() : callbackPrefix + options.funName;

                // 确保 staticType 是数字类型
                options.staticType = options.staticType === 0 ? options.staticType : 0;

                // 将回调函数存储到 registeredCallbacks 中
                registeredCallbacks[callbackKey] = options.reFun;
            }

            // 执行实际的调用逻辑
            (function (callOptions) {
                // 记录原始调用参数
                enableLog && console.log("001" + JSON.stringify(callOptions));

                // 获取用户代理信息
                var userAgent = navigator.userAgent;

                // 判断平台类型
                var isAndroid = /Android|Adr/i.test(userAgent);
                var isIOS = /\(i[^;]+;( U;)? CPU.+Mac OS X/.test(userAgent);
                var isInApp = /-1 < o.indexOf(a) || !0/.test("判断逻辑");  // 这里可能是一个占位符，需根据实际情况调整

                // 如果是 Android 并且符合特定条件
                if (isAndroid && isInApp) {
                    enableLog && console.log("002");
                    // 调用 Android 原生方法
                    window.coreyl.pushFun(JSON.stringify(callOptions));
                }

                // 如果是 iOS 并且符合特定条件
                if (isIOS && isInApp) {
                    enableLog && console.log("003");
                    // 调用 iOS 原生方法
                    window.webkit.messageHandlers.core.postMessage(JSON.stringify(callOptions));
                }
            })({
                funName: options.funName,
                param: options.param ? options.param : null,
                reFun: callbackKey || null
            });
        },

        /**
         * 使用 jsbridge 接收来自原生应用的响应。
         *
         * @param {string} response - 原生应用返回的响应数据
         */
        use: function (response) {
            try {
                // 解析响应数据
                try {
                    if (typeof response === "string") {
                        response = JSON.parse(response.replace(/\n/g, "\\n").replace(/\t/g, "\\t"));
                    }
                } catch (e) {
                    if(enableLog){console.warn("005：响应数据解析失败",e)};
                }

                // 提取函数消息部分
                var functionMessage = response.funMsg;
                try {
                    if (typeof functionMessage === "string") {
                        functionMessage = JSON.parse(functionMessage);
                    }
                } catch (e) {
                    enableLog && console.warn("006：funMsg 数据解析失败");
                }

                // 记录接收的函数消息
                enableLog && console.log("007---------------------->");
                enableLog && console.log(JSON.stringify(functionMessage));

                // 检查是否存在对应的回调函数
                if (typeof functionMessage.reFun === "string" && functionMessage.reFun.indexOf(callbackPrefix) !== -1) {
                    // 处理成功情况
                    if (parseInt(response.errorCode) === 0) {
                        enableLog && console.log("008-------------->");

                        // 执行 onSuccess 回调
                        try {
                            registeredCallbacks[functionMessage.reFun].onSuccess({
                                errorCode: response.errorCode,
                                errorMsg: response.errorMsg,
                                param: response.callBackParam
                            });
                        } catch (e) {
                            enableLog && console.error("009：执行 onSuccess 回调时发生异常", e);
                        }

                        // 如果包含 config 字段，执行 readydo
                        if (functionMessage.reFun.indexOf(callbackPrefix + "config") !== -1) {
                            window.yl.readydo();
                        }
                    } else {
                        // 处理失败情况
                        enableLog && console.log("010-------------->");
                        try {
                            registeredCallbacks[functionMessage.reFun].onFail({
                                errorCode: response.errorCode,
                                errorMsg: response.errorMsg
                            });
                        } catch (e) {
                            enableLog && console.error("011：执行 onFail 回调时发生异常", e);
                        }
                    }

                    // 如果是临时回调，删除它
                    if (registeredCallbacks[functionMessage.reFun].staticType === 0) {
                        delete registeredCallbacks[functionMessage.reFun];
                    }
                }

                // 返回原始响应数据
                return response;
            } catch (e) {
                enableLog && console.warn("012：处理响应时发生异常", e);
            }
        },

        /**
         * 检查是否有 coreyll.pushFun 方法可用。
         */
        has: function () {
            if (window.coreyll && window.coreyll.pushFun) {
                window.coreyll.pushFun("1");
            } else {
                enableLog && console.warn("coreyll.pushFun 方法不可用");
            }
        },

        /**
         * 准备就绪，通知原生应用。
         */
        ready: function () {
            if (window.yl) {
                enableLog && console.log("013：调用 yl.hasReady()");
                window.yl.hasReady();
            } else {
                enableLog && console.warn("yl 对象不存在，无法调用 hasReady()");
            }
        }
    };
})();